==> quasar-framework-0.15.6.tgz: package/icons/fontawesome-pro.js <==
export default {
  name: 'fontawesome-light',
  type: {
    positive: 'fal fa-check',
    negative: 'fal fa-exclamation-triangle',
    info: 'fal fa-info-circle',
    warning: 'fal fa-exclamation'
  },
  arrow: {
    up: 'fal fa-arrow-up',
    right: 'fal fa-arrow-right',
    down: 'fal fa-arrow-down',
    left: 'fal fa-arrow-left'
  },
  chevron: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },

  pullToRefresh: {
    arrow: 'fal fa-arrow-alt-circle-down',
    refresh: 'fal fa-sync-alt'
  },
  search: {
    icon: 'fal fa-search',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times'
  },
  carousel: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right', // TODO
    quickNav: 'fal fa-circle'
  },
  checkbox: { // TODO
    checked: {
      ios: 'fal fa-check-circle',
      mat: 'fal fa-check-square'
    },
    unchecked: {
      ios: 'fal fa-circle',
      mat: 'fal fa-square'
    },
    indeterminate: {
      ios: 'fal fa-minus-circle',
      mat: 'fal fa-minus-square'
    }
  },
  chip: {
    close: 'fal fa-times-circle'
  },
  chipsInput: {
    add: 'fal fa-paper-plane'
  },
  collapsible: {
    icon: 'fal fa-chevron-down'
  },
  datetime: {
    arrowLeft: 'fal fa-chevron-left',
    arrowRight: 'fal fa-chevron-right'
  },
  editor: {
    bold: 'fal fa-bold',
    italic: 'fal fa-italic',
    strikethrough: 'fal fa-strikethrough',
    underline: 'fal fa-underline',
    unorderedList: 'fal fa-list-ul',
    orderedList: 'fal fa-list-ol',
    subscript: 'fal fa-subscript',
    superscript: 'fal fa-superscript',
    hyperlink: 'fal fa-link',
    toggleFullscreen: 'fal fa-expand-arrows-alt',
    quote: 'fal fa-quote-right',
    left: 'fal fa-align-left',
    center: 'fal fa-align-center',
    right: 'fal fa-align-right',
    justify: 'fal fa-align-justify',
    print: 'fal fa-print',
    outdent: 'fal fa-outdent',
    indent: 'fal fa-indent',
    removeFormat: 'fal fa-eraser',
    formatting: 'fal fa-heading',
    fontSize: 'fal fa-text-height',
    align: 'fal fa-align-left',
    hr: 'fal fa-minus-square',
    undo: 'fal fa-undo',
    redo: 'fal fa-redo',
    header: 'fal fa-heading',
    code: 'fal fa-code',
    size: 'fal fa-text-height',
    font: 'fal fa-font'
  },
  fab: {
    icon: 'fal fa-plus',
    activeIcon: 'fal fa-times'
  },
  input: {
    showPass: 'fal fa-eye',
    hidePass: 'fal fa-eye-slash',
    showNumber: 'fal fa-calculator',
    hideNumber: 'fal fa-keyboard',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times',
    dropdown: 'fal fa-caret-down'
  },
  pagination: {
    first: 'fal fa-step-backward',
    prev: 'fal fa-chevron-left',
    next: 'fal fa-chevron-right',
    last: 'fal fa-step-forward'
  },
  radio: {
    checked: {
      ios: 'fal fa-check',
      mat: 'fal fa-check-circle'
    },
    unchecked: {
      ios: '',
      mat: 'fal fa-circle'
    }
  },
  rating: {
    icon: 'fal fa-star'
  },
  stepper: {
    done: 'fal fa-check',
    active: 'fal fa-pencil-alt',
    error: 'fal fa-exclamation-triangle'
  },
  tabs: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },
  table: {
    arrowUp: 'fal fa-long-arrow-up',
    warning: 'fal fa-exclamation-triangle',
    prevPage: 'fal fa-chevron-left',
    nextPage: 'fal fa-chevron-right'
  },
  tree: {
    icon: 'fal fa-play'
  },
  uploader: {
    done: 'fal fa-check',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times',
    add: 'fal fa-plus-square',
    upload: 'fal fa-cloud-upload-alt',
    expand: 'fal fa-chevron-down',
    file: 'fal fa-file'
  }
}

==> quasar-framework-0.15.8.tgz: package/icons/fontawesome-pro.js <==
export default {
  name: 'fontawesome-light',
  type: {
    positive: 'fal fa-check',
    negative: 'fal fa-exclamation-triangle',
    info: 'fal fa-info-circle',
    warning: 'fal fa-exclamation'
  },
  arrow: {
    up: 'fal fa-arrow-up',
    right: 'fal fa-arrow-right',
    down: 'fal fa-arrow-down',
    left: 'fal fa-arrow-left'
  },
  chevron: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },

  pullToRefresh: {
    arrow: 'fal fa-arrow-alt-circle-down',
    refresh: 'fal fa-sync-alt'
  },
  search: {
    icon: 'fal fa-search',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times'
  },
  carousel: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right', // TODO
    quickNav: 'fal fa-circle'
  },
  checkbox: { // TODO
    checked: {
      ios: 'fal fa-check-circle',
      mat: 'fal fa-check-square'
    },
    unchecked: {
      ios: 'fal fa-circle',
      mat: 'fal fa-square'
    },
    indeterminate: {
      ios: 'fal fa-minus-circle',
      mat: 'fal fa-minus-square'
    }
  },
  chip: {
    close: 'fal fa-times-circle'
  },
  chipsInput: {
    add: 'fal fa-paper-plane'
  },
  collapsible: {
    icon: 'fal fa-caret-down'
  },
  datetime: {
    arrowLeft: 'fal fa-chevron-left',
    arrowRight: 'fal fa-chevron-right'
  },
  editor: {
    bold: 'fal fa-bold',
    italic: 'fal fa-italic',
    strikethrough: 'fal fa-strikethrough',
    underline: 'fal fa-underline',
    unorderedList: 'fal fa-list-ul',
    orderedList: 'fal fa-list-ol',
    subscript: 'fal fa-subscript',
    superscript: 'fal fa-superscript',
    hyperlink: 'fal fa-link',
    toggleFullscreen: 'fal fa-expand-arrows-alt',
    quote: 'fal fa-quote-right',
    left: 'fal fa-align-left',
    center: 'fal fa-align-center',
    right: 'fal fa-align-right',
    justify: 'fal fa-align-justify',
    print: 'fal fa-print',
    outdent: 'fal fa-outdent',
    indent: 'fal fa-indent',
    removeFormat: 'fal fa-eraser',
    formatting: 'fal fa-heading',
    fontSize: 'fal fa-text-height',
    align: 'fal fa-align-left',
    hr: 'fal fa-minus-square',
    undo: 'fal fa-undo',
    redo: 'fal fa-redo',
    header: 'fal fa-heading',
    code: 'fal fa-code',
    size: 'fal fa-text-height',
    font: 'fal fa-font'
  },
  fab: {
    icon: 'fal fa-plus',
    activeIcon: 'fal fa-times'
  },
  input: {
    showPass: 'fal fa-eye',
    hidePass: 'fal fa-eye-slash',
    showNumber: 'fal fa-calculator',
    hideNumber: 'fal fa-keyboard',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times',
    dropdown: 'fal fa-caret-down'
  },
  pagination: {
    first: 'fal fa-step-backward',
    prev: 'fal fa-chevron-left',
    next: 'fal fa-chevron-right',
    last: 'fal fa-step-forward'
  },
  radio: {
    checked: {
      ios: 'fal fa-check',
      mat: 'fal fa-check-circle'
    },
    unchecked: {
      ios: '',
      mat: 'fal fa-circle'
    }
  },
  rating: {
    icon: 'fal fa-star'
  },
  stepper: {
    done: 'fal fa-check',
    active: 'fal fa-pencil-alt',
    error: 'fal fa-exclamation-triangle'
  },
  tabs: {
    left: 'fal fa-chevron-left',
    right: 'fal fa-chevron-right'
  },
  table: {
    arrowUp: 'fal fa-long-arrow-up',
    warning: 'fal fa-exclamation-triangle',
    prevPage: 'fal fa-chevron-left',
    nextPage: 'fal fa-chevron-right'
  },
  tree: {
    icon: 'fal fa-play'
  },
  uploader: {
    done: 'fal fa-check',
    clear: 'fal fa-times-circle',
    clearInverted: 'fal fa-times',
    add: 'fal fa-plus-square',
    upload: 'fal fa-cloud-upload-alt',
    expand: 'fal fa-chevron-down',
    file: 'fal fa-file'
  }
}
